Package: treePlotArea
Title: Correction Factors for Tree Plot Areas Intersected by Stand
        Boundaries
Version: 3.1.0
Authors@R: 
    c(person("Andreas Dominik", "Cullmann", , "fvafrcu@mailbox.org", 
    role = c("aut", "cre")),
    person(given = "Bernhard",
             family = "Bösch",
             role = "ctb"),
    person(given = "Christoph",
             family = "Fischer",
             role = "ctb"),
    person(given = "Gerald",
             family = "Kändler",
             role = "ctb")
             )
Description: The German national forest inventory uses angle count sampling, 
    a sampling method first published as `Bitterlich, W.: Die Winkelzählmessung.
    Allgemeine Forst- und Holzwirtschaftliche Zeitung, 58. Jahrg., Folge 11/12 
    vom Juni 1947` and extended by Grosenbaugh
    (<https://academic.oup.com/jof/article-abstract/50/1/32/4684174>)
    as probability proportional to size sampling.
    When plots are located near stand boundaries, their sizes and hence
    their probabilities need to be corrected.
License: BSD_2_clause + file LICENSE
URL: https://gitlab.com/fvafrcu/treeplotarea.git
Depends: R (>= 4.0.0)
Imports: fritools, graphics, sf, stats
Suggests: checkmate, pkgload, plotrix, rmarkdown, rprojroot, RUnit,
        testthat, tinytest
VignetteBuilder: utils
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2025-11-25 20:21:27 UTC; qwer
Author: Andreas Dominik Cullmann [aut, cre],
  Bernhard Bösch [ctb],
  Christoph Fischer [ctb],
  Gerald Kändler [ctb]
Maintainer: Andreas Dominik Cullmann <fvafrcu@mailbox.org>
Repository: CRAN
Date/Publication: 2025-11-25 20:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 10:52:41 UTC; unix
