# Generated by roxygen2: do not edit by hand

export(bw2bwi2022de)
export(bwi2cartesian)
export(check_boundaries)
export(get_boundary_polygons)
export(get_boundary_radius)
export(get_correction_factors)
export(get_defaults)
export(get_intersection)
export(get_r_max)
export(orthogonal)
export(plot_tree_plot_area)
export(points2equation)
export(secant_intersections)
export(select_valid_angle_count_trees)
export(set_options)
export(validate_data)
export(vector_length)
